pub enum MappingProviderRequest {
OpenSession {
session: ServerEnd<MappingSessionMarker>,
responder: MappingProviderOpenSessionResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: MappingProviderControlHandle,
method_type: MethodType,
},
}Variants
OpenSession
Establishes a new mapping session, returning the mapping VMO.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: MappingProviderControlHandle
method_type: MethodTypeImplementations
Sourceimpl MappingProviderRequest
impl MappingProviderRequest
pub fn into_open_session( self, ) -> Option<(ServerEnd<MappingSessionMarker>, MappingProviderOpenSessionResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL