pub enum MappingSessionRequest {
Open {
key: u64,
identifier: Vec<u8>,
responder: MappingSessionOpenResponder,
},
Close {
key: u64,
responder: MappingSessionCloseResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: MappingSessionControlHandle,
method_type: MethodType,
},
}Variants
Open
Registers a node’s extents in the mapping session, returning its uncompressed size in bytes.
The filesystem resolves the identifier to locate the node on disk and transmits its
extent mappings to the block driver associated with key.
Close
Unregisters a node’s extents from the session by its session-unique key.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: MappingSessionControlHandle
method_type: MethodTypeImplementations
Sourceimpl MappingSessionRequest
impl MappingSessionRequest
pub fn into_open(self) -> Option<(u64, Vec<u8>, MappingSessionOpenResponder)>
pub fn into_close(self) -> Option<(u64, MappingSessionCloseResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL