pub struct MappingProviderMarker;Trait Implementations
Sourceimpl Clone for MappingProviderMarker
impl Clone for MappingProviderMarker
Sourcefn clone(&self) -> MappingProviderMarker
fn clone(&self) -> MappingProviderMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MappingProviderMarker
Sourceimpl Debug for MappingProviderMarker
impl Debug for MappingProviderMarker
Sourceimpl DiscoverableProtocolMarker for MappingProviderMarker
impl DiscoverableProtocolMarker for MappingProviderMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for MappingProviderMarker
Sourceimpl Hash for MappingProviderMarker
impl Hash for MappingProviderMarker
Sourceimpl Ord for MappingProviderMarker
impl Ord for MappingProviderMarker
Sourcefn cmp(&self, other: &MappingProviderMarker) -> Ordering
fn cmp(&self, other: &MappingProviderMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MappingProviderMarker
impl PartialEq for MappingProviderMarker
Sourceimpl PartialOrd for MappingProviderMarker
impl PartialOrd for MappingProviderMarker
Sourceimpl ProtocolMarker for MappingProviderMarker
impl ProtocolMarker for MappingProviderMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.storage.mapping.MappingProvider"
const DEBUG_NAME: &'static str = "fuchsia.storage.mapping.MappingProvider"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MappingProviderProxy
type Proxy = MappingProviderProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MappingProviderRequestStream
type RequestStream = MappingProviderRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MappingProviderSynchronousProxy
type SynchronousProxy = MappingProviderSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MappingProviderMarker