pub struct MappingProviderOpenSessionResponse {
pub mapping_vmo: Vmo,
}Fields
mapping_vmo: VmoTrait Implementations
Sourceimpl Decode<MappingProviderOpenSessionResponse, DefaultFuchsiaResourceDialect> for MappingProviderOpenSessionResponse
impl Decode<MappingProviderOpenSessionResponse, DefaultFuchsiaResourceDialect> for MappingProviderOpenSessionResponse
Sourceimpl Encode<MappingProviderOpenSessionResponse, DefaultFuchsiaResourceDialect> for &mut MappingProviderOpenSessionResponse
impl Encode<MappingProviderOpenSessionResponse, DefaultFuchsiaResourceDialect> for &mut MappingProviderOpenSessionResponse
Sourceimpl<T0: Encode<HandleType<Vmo, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<MappingProviderOpenSessionResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<HandleType<Vmo, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<MappingProviderOpenSessionResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl Eq for MappingProviderOpenSessionResponse
Sourceimpl Ord for MappingProviderOpenSessionResponse
impl Ord for MappingProviderOpenSessionResponse
Sourcefn cmp(&self, other: &MappingProviderOpenSessionResponse) -> Ordering
fn cmp(&self, other: &MappingProviderOpenSessionResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for MappingProviderOpenSessionResponse
impl PartialOrd for MappingProviderOpenSessionResponse
Sourceimpl ResourceTypeMarker for MappingProviderOpenSessionResponse
impl ResourceTypeMarker for MappingProviderOpenSessionResponse
Sourcetype Borrowed<'a> = &'a mut MappingProviderOpenSessionResponse
type Borrowed<'a> = &'a mut MappingProviderOpenSessionResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for MappingProviderOpenSessionResponse
impl StructuralPartialEq for MappingProviderOpenSessionResponse
Sourceimpl TypeMarker for MappingProviderOpenSessionResponse
impl TypeMarker for MappingProviderOpenSessionResponse
Sourcetype Owned = MappingProviderOpenSessionResponse
type Owned = MappingProviderOpenSessionResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for MappingProviderOpenSessionResponse
impl RefUnwindSafe for MappingProviderOpenSessionResponse
impl Send for MappingProviderOpenSessionResponse
impl Sync for MappingProviderOpenSessionResponse
impl Unpin for MappingProviderOpenSessionResponse
impl UnsafeUnpin for MappingProviderOpenSessionResponse
impl UnwindSafe for MappingProviderOpenSessionResponse