pub struct MappingProviderProxy { /* private fields */ }Implementations
Sourceimpl MappingProviderProxy
impl MappingProviderProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.storage.mapping/MappingProvider.
Sourcepub fn take_event_stream(&self) -> MappingProviderEventStream
pub fn take_event_stream(&self) -> MappingProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn open_session(
&self,
session: ServerEnd<MappingSessionMarker>,
) -> QueryResponseFut<MappingProviderOpenSessionResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn open_session( &self, session: ServerEnd<MappingSessionMarker>, ) -> QueryResponseFut<MappingProviderOpenSessionResult, DefaultFuchsiaResourceDialect> ⓘ
Establishes a new mapping session, returning the mapping VMO.