pub struct MappingProviderSynchronousProxy { /* private fields */ }Implementations
Sourceimpl MappingProviderSynchronousProxy
impl MappingProviderSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<MappingProviderEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<MappingProviderEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn open_session(
&self,
session: ServerEnd<MappingSessionMarker>,
___deadline: MonotonicInstant,
) -> Result<MappingProviderOpenSessionResult, Error>
pub fn open_session( &self, session: ServerEnd<MappingSessionMarker>, ___deadline: MonotonicInstant, ) -> Result<MappingProviderOpenSessionResult, Error>
Establishes a new mapping session, returning the mapping VMO.