pub struct MappingSessionMarker;Trait Implementations
Sourceimpl Clone for MappingSessionMarker
impl Clone for MappingSessionMarker
Sourcefn clone(&self) -> MappingSessionMarker
fn clone(&self) -> MappingSessionMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MappingSessionMarker
Sourceimpl Debug for MappingSessionMarker
impl Debug for MappingSessionMarker
impl Eq for MappingSessionMarker
Sourceimpl Hash for MappingSessionMarker
impl Hash for MappingSessionMarker
Sourceimpl Ord for MappingSessionMarker
impl Ord for MappingSessionMarker
Sourcefn cmp(&self, other: &MappingSessionMarker) -> Ordering
fn cmp(&self, other: &MappingSessionMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MappingSessionMarker
impl PartialEq for MappingSessionMarker
Sourceimpl PartialOrd for MappingSessionMarker
impl PartialOrd for MappingSessionMarker
Sourceimpl ProtocolMarker for MappingSessionMarker
impl ProtocolMarker for MappingSessionMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) MappingSession"
const DEBUG_NAME: &'static str = "(anonymous) MappingSession"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MappingSessionProxy
type Proxy = MappingSessionProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MappingSessionRequestStream
type RequestStream = MappingSessionRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MappingSessionSynchronousProxy
type SynchronousProxy = MappingSessionSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MappingSessionMarker