pub struct MappingSessionOpenRequest {
pub key: u64,
pub identifier: Vec<u8>,
}Fields
key: u64Session-unique numeric handle allocated by the client. The filesystem associates the node’s disk extents with this key when communicating with the block driver.
identifier: Vec<u8>Content identifier for the node (e.g. 32-byte blob Merkle root hash) used by the filesystem to look up its extents on disk.