pub struct MappingSessionProxy { /* private fields */ }Implementations
Sourceimpl MappingSessionProxy
impl MappingSessionProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.storage.mapping/MappingSession.
Sourcepub fn take_event_stream(&self) -> MappingSessionEventStream
pub fn take_event_stream(&self) -> MappingSessionEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn open(
&self,
key: u64,
identifier: &[u8],
) -> QueryResponseFut<MappingSessionOpenResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn open( &self, key: u64, identifier: &[u8], ) -> QueryResponseFut<MappingSessionOpenResult, DefaultFuchsiaResourceDialect> ⓘ
Registers a node’s extents in the mapping session, returning its uncompressed size in bytes.
The filesystem resolves the identifier to locate the node on disk and transmits its
extent mappings to the block driver associated with key.
Sourcepub fn close(
&self,
key: u64,
) -> QueryResponseFut<MappingSessionCloseResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn close( &self, key: u64, ) -> QueryResponseFut<MappingSessionCloseResult, DefaultFuchsiaResourceDialect> ⓘ
Unregisters a node’s extents from the session by its session-unique key.