MappingSessionSynchronousProxy

Struct MappingSessionSynchronousProxy 

pub struct MappingSessionSynchronousProxy { /* private fields */ }

Implementations

Source

impl MappingSessionSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<MappingSessionEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn open( &self, key: u64, identifier: &[u8], ___deadline: MonotonicInstant, ) -> Result<MappingSessionOpenResult, Error>

Registers a node’s extents in the mapping session, returning its uncompressed size in bytes.

The filesystem resolves the identifier to locate the node on disk and transmits its extent mappings to the block driver associated with key.

pub fn close( &self, key: u64, ___deadline: MonotonicInstant, ) -> Result<MappingSessionCloseResult, Error>

Unregisters a node’s extents from the session by its session-unique key.